Modules
- error
- This module contains error and result types for htsget-axum.
- handlers
- middleware
- Middleware components for the htsget-rs server.
- server
- The following module provides an implementation of the data and ticket servers using Axum.
Structs
- Router
- The router type for composing handlers and services.